# Welcome to PocketPose Projects!

This section is dedicated to projects developed by the PocketPose community. If you have a project you would like to share, please submit a pull request to add it to this list.

## Project List

- [PocketPose Webcam Demo](./webcam-demo): A simple webcam demo that uses PocketPose to detect poses in real-time.